@@ -4,7 +4,7 @@
 # hashcash.pl - Wallet for HashCash Digital Cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: bin/hashcash.pl v1.118 Sat Jun 10 13:59:11 PDT 2017 $
+# $Id: bin/hashcash.pl v1.119 Sun Jun 11 21:21:32 PDT 2017 $
 
 use warnings;
 
@@ -21,7 +21,7 @@ use Crypt::Diceware;
 use GD::Barcode::QRcode;
 use File::HomeDir;
 
-my $HASHCASH = File::HomeDir->my_home . '/.hashcash';
+my $HASHCASH = $ENV{HASHCASHDIR} || File::HomeDir->my_home . '/.hashcash';
 
 # Get vault configs, default to first vault
 my @vaults = map { new Persistence::Object::Simple ('__Fn' => $_) } glob("$HASHCASH/vaults/*.cfg");
@@ -1043,8 +1043,8 @@ hashcash.pl - Wallet for HashCash digital cash
 
 =head1 VERSION
 
- $Revision: 1.118 $
- $Date: Sat Jun 10 13:59:11 PDT 2017 $
+ $Revision: 1.119 $
+ $Date: Sun Jun 11 21:21:32 PDT 2017 $
 
 =head1 SYNOPSIS
 
