@@ -4,7 +4,7 @@
 # vault.pl - Vault server for HashCash digital cash
 # Copyright (c) 2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: bin/vault.pl v1.118 Sat Jun 10 13:59:12 PDT 2017 $
+# $Id: bin/vault.pl v1.119 Sun Jun 11 21:21:32 PDT 2017 $
 
 use strict;
 use warnings;
@@ -20,9 +20,13 @@ use Crypt::HashCash qw (_dec _hex);
 use Crypt::EECDH;
 use Digest::MD5 qw(md5_hex);
 use Net::Server::PreFork;
+use File::HomeDir;
 use Crypt::CBC;
 
-my $vault = new Crypt::HashCash::Vault::Bitcoin;
+my $HASHCASH = $ENV{HASHCASHDIR} || File::HomeDir->my_home . '/.hashcash';
+
+my $vault = new Crypt::HashCash::Vault::Bitcoin ( DB => "$HASHCASH/vault.db",
+						  KeyDB => "$HASHCASH/vaults/vault.key" );
 
 if (defined $ARGV[0] and $ARGV[0] eq '--keygen') {
   $vault->keygen( Name   => 'HashCash.ch',
@@ -81,8 +85,8 @@ vault.pl - Vault for HashCash digital cash
 
 =head1 VERSION
 
- $Revision: 1.118 $
- $Date: Sat Jun 10 13:59:12 PDT 2017 $
+ $Revision: 1.119 $
+ $Date: Sun Jun 11 21:21:32 PDT 2017 $
 
 =head1 SYNOPSIS
 
