@@ -3,7 +3,7 @@
 # Crypt::HashCash::Mint - Mint for HashCash digital cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Mint.pm v1.118 Sat Jun 10 13:59:11 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Mint.pm v1.119 Sun Jun 11 21:21:31 PDT 2017 $
 
 package Crypt::HashCash::Mint;
 
@@ -18,7 +18,7 @@ use Persistence::Object::Simple;
 use vars qw( $VERSION $AUTOLOAD );
 use DBI;
 
-our ( $VERSION ) = '$Revision: 1.118 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.119 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -30,15 +30,19 @@ sub new {
 		     COMMENT        =>   '',
 		     DEBUG          =>   $arg{Debug} || 0,
 		     KEYSIZE        =>   1024,
-		     KEYDB          =>   $arg{KeyDB} || '/tmp/key.db',
+		     KEYDB          =>   $arg{KeyDB} || '/tmp/vault.key',
 		     DENOMS         =>   [qw(100 200 500 1000 2000 5000 10000 20000 50000 100000 200000
 					     500000 1000000 2000000 5000000 10000000 20000000 50000000
 					     100000000 200000000 500000000 1000000000)],
-		     SPENTDB        =>   $arg{SpentDB} || '/tmp/spent.db'
+		     DB             =>   $arg{DB}
 		   }, $class;
   return unless my $keydb = new Persistence::Object::Simple ('__Fn' => $self->keydb); $self->keydb($keydb);
-  unlink $self->spentdb if $arg{Clobber};
-  my $db = DBI->connect('dbi:SQLite:dbname=' . $self->spentdb ,undef, undef, {AutoCommit => 1});
+  my $db = $self->db;
+  unless ($db) {
+    unlink $arg{SpentDB} if defined $arg{SpentDB} and $arg{SpentDB} ne ':memory:' and $arg{Clobber};
+    return unless $db = DBI->connect("dbi:SQLite:dbname=$arg{SpentDB}", undef, undef, {AutoCommit => 1});
+    $self->{DB} = $db;
+  }
   my @tables = $db->tables('%','%','spent','TABLE');
   unless ($tables[0]) {
     if ($arg{Create}) {
@@ -52,7 +56,6 @@ sub new {
       return undef;
     }
   }
-  $self->{DB} = $db;
   return $self;
 }
 
@@ -176,8 +179,8 @@ Crypt::HashCash::Mint - Mint for HashCash digital cash
 
 =head1 VERSION
 
- $Revision: 1.118 $
- $Date: Sat Jun 10 13:59:11 PDT 2017 $
+ $Revision: 1.119 $
+ $Date: Sun Jun 11 21:21:31 PDT 2017 $
 
 =head1 SYNOPSIS
 
